==> haskell-resource-pool-0.2.3.2-54-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-resource-pool.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: resource-pool
version: 0.2.3.2
id: resource-pool-0.2.3.2-93Oz3id2RemIkByo3JJErO
key: resource-pool-0.2.3.2-93Oz3id2RemIkByo3JJErO
license: BSD-3-Clause
copyright: Copyright 2011 MailRank, Inc.
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>,
            Bas van Dijk <v.dijk.bas@gmail.com>
author: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: http://github.com/bos/pool
synopsis: A high-performance striped resource pooling implementation
description:
    A high-performance striped pooling abstraction for managing
    flexibly-sized collections of resources such as database
    connections.
category: Data, Database, Network
abi: b2c6e53fb12b730b0ce938a053403513
exposed: True
exposed-modules:
    Data.Pool
import-dirs: /usr/lib/ghc-8.6.3/site-local/resource-pool-0.2.3.2
library-dirs: /usr/lib/ghc-8.6.3/site-local/resource-pool-0.2.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/resource-pool-0.2.3.2
hs-libraries: HSresource-pool-0.2.3.2-93Oz3id2RemIkByo3JJErO
depends:
    base-4.12.0.0 hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    monad-control-1.0.2.3-2zhblvoGozsIFfDVW4DMdn stm-2.5.0.0
    time-1.8.0.2 transformers-0.5.5.0
    transformers-base-0.4.5.2-GVqlM7MFCpoHJlEFRaTwrG
    vector-0.12.0.2-5G85DK6NPIx1LphnqJy7eO
haddock-interfaces: /usr/share/doc/haskell-resource-pool/html/resource-pool.haddock
haddock-html: /usr/share/doc/haskell-resource-pool/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-resource-pool-0.2.3.2-55-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-resource-pool.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: resource-pool
version: 0.2.3.2
id: resource-pool-0.2.3.2-9X2QGu45K2x9TGF6uxNZts
key: resource-pool-0.2.3.2-9X2QGu45K2x9TGF6uxNZts
license: BSD-3-Clause
copyright: Copyright 2011 MailRank, Inc.
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>,
            Bas van Dijk <v.dijk.bas@gmail.com>
author: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: http://github.com/bos/pool
synopsis: A high-performance striped resource pooling implementation
description:
    A high-performance striped pooling abstraction for managing
    flexibly-sized collections of resources such as database
    connections.
category: Data, Database, Network
abi: 37fbbe844ff4f0f37b130e3781d35f60
exposed: True
exposed-modules:
    Data.Pool
import-dirs: /usr/lib/ghc-8.6.3/site-local/resource-pool-0.2.3.2
library-dirs: /usr/lib/ghc-8.6.3/site-local/resource-pool-0.2.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/resource-pool-0.2.3.2
hs-libraries: HSresource-pool-0.2.3.2-9X2QGu45K2x9TGF6uxNZts
depends:
    base-4.12.0.0 hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    monad-control-1.0.2.3-C7Mt0wi6Itk30zmrdYvypZ stm-2.5.0.0
    time-1.8.0.2 transformers-0.5.5.0
    transformers-base-0.4.5.2-CYvZwiYe2CEFBvY3nUdZ2C
    vector-0.12.0.2-5G85DK6NPIx1LphnqJy7eO
haddock-interfaces: /usr/share/doc/haskell-resource-pool/html/resource-pool.haddock
haddock-html: /usr/share/doc/haskell-resource-pool/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
